package com.kuyuntech.cofarcooking.device.sdk.devmode.core;

import com.kuyuntech.cofarcooking.device.sdk.constant.core.DevStatus;
import com.kuyuntech.cofarcooking.device.sdk.constant.core.HeatModes;
import com.kuyuntech.cofarcooking.device.sdk.constant.core.WorkModes;
import com.kuyuntech.cofarcooking.device.sdk.eventbus.core.DevInfo;
import com.kuyuntech.cofarcooking.device.sdk.util.core.CofarSDK;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.ToString;

import java.util.TimerTask;

@EqualsAndHashCode(callSuper = true)
@Data
@ToString
public class AdaptedCooking063 extends BaseDevMode{
    private boolean startCount = false;
    private boolean pasue = false;
    private boolean stop = false;
    private boolean isHeatTemps = false;

    public AdaptedCooking063(){

        this.setMode(WorkModes.ADAPTED_COOKING_HEAT);

        //时间
        this.setMinTime(0);
        this.setMaxTime(90 * 60);
        this.setDefaultTime(0);
        this.setTimeChange(true);

        //电机
        this.setDefaultMotorGear(0);
        this.setMaxMotorGear(0);
        this.setMaxMotorGear(12);
        this.setMotorGearChange(true);
        this.setMotorDirectionChange(true);

        //温度
        this.setDefaultTemp(0);
        this.setMinTemp(0);
        this.setMaxTemp(130);
        this.setTempChange(true);
        this.setDefaultHeatMode(HeatModes.SAP_SHUI);

    }


    @Override
    public boolean isTempChange() {


        if("3015".equals(CofarSDK.MODEL)||("033G").equals(CofarSDK.DEVICE_NUM)||("033H").equals(CofarSDK.DEVICE_NUM)){
            return super.isTempChange();
        }

        DevInfo info = CofarSDK.devInfo();


        int motorGear = info.getMotorGear();

        if(info.getMotorGearBuffer() != -1){
            motorGear = info.getMotorGearBuffer();
        }

        if(motorGear > 4  && motorGear < 12){
            return false;
        }


        if(motorGear == 4){
            return true;
        }

        if(motorGear == 12 ){
            return true;
        }



        return true;
    }

    @Override
    public void start() {
        this.startCount = false;
        this.stop = false;
        this.pasue = false;
        isHeatTemps = false;
        if (CofarSDK.devInfo().getTargetTemp()<100){
            this.setResetTempSetting(false);
            this.setResetTargetTemp(CofarSDK.devInfo().getTargetTemp());
            CofarSDK.cfgHeatNative((short) 100,HeatModes.SAP_SHUI);
        }else {
            this.setResetTempSetting(true);
            this.setResetTargetTemp(CofarSDK.devInfo().getTargetTemp());
            CofarSDK.cfgHeatNative(CofarSDK.devInfo().getTargetTemp(),HeatModes.SAP_SHUI);
        }
        super.start();
    }

    @Override
    public void pause() {
        this.startCount = false;
        this.pasue = true;
        CofarSDK.pauseNatvie();
    }

    @Override
    public void resume() {
        this.pasue = false;
        this.isHeatTemps = false;

        if (CofarSDK.devInfo().getTargetTemp()<100){
            this.setResetTempSetting(false);
            this.setResetTargetTemp(CofarSDK.devInfo().getTargetTemp());
            CofarSDK.cfgHeatNative((short) 100,HeatModes.SAP_SHUI);
        }else {
            this.setResetTempSetting(true);
            this.setResetTargetTemp(CofarSDK.devInfo().getTargetTemp());
            CofarSDK.cfgHeatNative(CofarSDK.devInfo().getTargetTemp(),HeatModes.SAP_SHUI);
        }


        CofarSDK.resumeNavtive();
    }

    @Override
    public void stop() {
        this.setResetTempSetting(true);
        this.setResetTargetTemp(CofarSDK.devInfo().getTargetTemp());
        this.startCount = false;
        this.stop = true;
        this.pasue = false;
        CofarSDK.stopNative();
        super.stop();
    }

    @Override
    public void stop(boolean tips) {
        this.setResetTempSetting(true);
        this.setResetTargetTemp(CofarSDK.devInfo().getTargetTemp());
        this.startCount = false;
        this.stop = true;
        this.pasue = false;
        super.stop(tips);
    }


    @Override
    public int getMinTemp() {

        return super.getMinTemp();
    }

    @Override
    public int getMaxTemp() {


            //033G和033H需要像 之前3015速度调整
        if("3015".equals(CofarSDK.MODEL)||
                ("033G").equals(CofarSDK.DEVICE_NUM)||("033H").equals(CofarSDK.DEVICE_NUM)){
            return super.getMaxTemp();
        }

        DevInfo info = CofarSDK.devInfo();


        int motorGear = info.getMotorGear();

        if(info.getMotorGearBuffer() != -1){
            motorGear = info.getMotorGearBuffer();
        }

        if(motorGear > 4  && motorGear < 12){
              return 0;
        }


        if(motorGear == 4){
            return 50;
        }

        if(motorGear == 12 ){
            return 50;
        }



        return 130;
    }


    @Override
    public int checkTime(int time) {

//        DevInfo devInfo = CofarSDK.devInfo();
//
//        if(devInfo.getMotorGear() >= 7){
//            if(time > 10 * 60){
//                return  10 * 60;
//            }
//        }

        return super.checkTime(time);
    }

    @Override
    public short checkMotorGear(byte gear) {

//        DevInfo devInfo = CofarSDK.devInfo();
//
//
//        if(gear >= 7){
//            if(devInfo.getTargetTime() > 10 * 6){
//                return  7;
//            }
//        }

        return super.checkMotorGear(gear);
    }

    @Override
    public void onCountDown(TimerTask timer) {
        super.onCountDown(timer);
        if(pasue){
            return;
        }



        DevInfo devInfo = CofarSDK.devInfo();


        if (DevStatus.PAUSE == devInfo.getStatus()) {
            return;
        }

        if (devInfo.getRemainTime() <= 0 && devInfo.getMode().isCountDown() && !stop) {
            this.stop();
            timer.cancel();
            return;
        }


        if (stop) {
            this.stop(false);
            timer.cancel();
            return;
        }

        if (devInfo.getTargetTemp()>=100){
            //当前温度大于100度的时候，转普通加热
            if(devInfo.getTemp()  >= 100){
                this.startCount = true;
                if (!isHeatTemps){
                    CofarSDK.cfgHeatNative(devInfo.getTargetTemp(),HeatModes.PU_TONG);
                    isHeatTemps = true;
                }

            }
        }else {
            if (devInfo.getTemp()>=devInfo.getTargetTemp()){
                if (!isHeatTemps){
                    CofarSDK.cfgHeatNative(devInfo.getTargetTemp(),HeatModes.PU_TONG);
                    isHeatTemps = true;
                }
            }
        }



        devInfo.setRemainTime((short) (devInfo.getRemainTime() - 1));




    }


    public boolean startCountTime() {
        DevInfo info = CofarSDK.devInfo();
        if (info.getTargetTemp() >= 100) {
            if (info.getTemp() >= 100) {
                this.startCount = true;
                if (!this.isHeatTemps) {
                    CofarSDK.cfgHeatNative(info.getTargetTemp(), (byte)0);
                    this.isHeatTemps = true;
                }
            }
        } else if (info.getTemp() >= info.getTargetTemp() && !this.isHeatTemps) {
            CofarSDK.cfgHeatNative(info.getTargetTemp(), (byte)0);
            this.isHeatTemps = true;
        }

        return true;
    }



}
